covid19data: Extract COVID-19 data

Description Usage Arguments Value Author(s) Examples

View source: R/covid19data.R

Description

This function extracts the COVID-19 from the JHU github account. The dowloaded data contains 5 variables : data, iso3c code, confirmed, deaths and recovered You can choose the set of coutries and the range of dates

Usage

1
covid19data(country = "all", start = "2020-01-01", end = "2020-09-22")

Arguments

country

is the iso3c of the countries, by default it's "all". This variable is a vector

start

is the starting date. By default it's equal to "2020-01-02"

end

is the ending data

Value

A dataframe class with 5 variables

Author(s)

Dhafer Malouche

Examples

1
2
3
4
## Not run: 
dt=covid19data(country = "TUN",start = "2020-04-01",end = "2020-06-25")

## End(Not run)

malouche/c19stat documentation built on Oct. 5, 2020, 4:43 p.m.