Description Usage Arguments Value Author(s) Examples
This function extracts the COVID-19 from the JHU github account. The dowloaded data contains 5 variables : data, iso3c code, confirmed, deaths and recovered You can choose the set of coutries and the range of dates
1 | covid19data(country = "all", start = "2020-01-01", end = "2020-09-22")
|
country |
is the iso3c of the countries, by default it's "all". This variable is a vector |
start |
is the starting date. By default it's equal to "2020-01-02" |
end |
is the ending data |
A dataframe class with 5 variables
Dhafer Malouche
1 2 3 4 | ## Not run:
dt=covid19data(country = "TUN",start = "2020-04-01",end = "2020-06-25")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.